<?php
/*
Plugin Name: Wpcheck
Plugin URI: http://www.pagasa.net/wpcheck-un-plugin-pour-verifier-votre-wordpress/
Description: Check system, Wordpress, cron, PHP and compute performances. Also provide a fully downloadable report useful for debugging purposes.
Author: Thibaut Maquet
Version: 1.01
Author URI: http://www.pagasa.net/
*/
function wpcheck_init() {
  require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
  global $wpdb;
}
function wpcheck_deinit() {
}
function wpcheck_admin_settings() {
  if (function_exists('add_options_page')){
    add_options_page("Wpcheck", "Wpcheck", 'manage_options', 'wpcheck-admin-page', "wpcheck_display_settings");
  }
}

function wpcheck_function_enabled($mf) {
    return is_callable($mf) && false === stripos(ini_get('disable_functions'), $mf);
}

function wpcheck_styles($hook) {
  if($hook != 'settings_page_wpcheck-admin-page') 
    return;
  if (!defined('WPCHECK_PLUGIN_PATH')) 
    define('WPCHECK_PLUGIN_PATH', plugin_dir_url(__FILE__));
  wp_register_style('wpcheck-custom-style', WPCHECK_PLUGIN_PATH .'wpcheck.css');
  wp_enqueue_style('wpcheck-custom-style');
}

function wpcheck_write($a1,$a2,$i) {
  
  if(!$i)
    $a = "<tr><td>".$a1."</td><td><strong>".$a2."</strong></td></tr>\n";
  else {
    $a = $a1.": ".$a2."\n";
  }
  return $a;
}

function wpcheck_report() {
  $fd = fopen(plugin_dir_path( __FILE__ ) ."wpcheck.html","w");
  if($fd) {
    $a = "";
    $a .= "<html><head>";
    $a .= "<title>WPCheck report</title>";
    $a .= "</head><body>";
    $a .= "<h3>System</h3>";
    $a .= wpcheck_sys();
    $a .= "<h3>Performances</h3>";
    $a .= wpcheck_performances();
    $a .= "<h3>Cron Entries</h3>";
    $a .= wpcheck_cron();   
    $a .= "<h3>Wordpress settings</h3>";
    $a .= wpcheck_wordpress();
    $a .= "<h3>PHP</h3>";
    $a .= wpcheck_php();
    $a .= "</body></html>";
    fwrite($fd,$a);
    fclose($fd); 
    $a = 'Report was created. <a href="'.WPCHECK_PLUGIN_PATH.'/wpcheck.html">Download</a>';
  }
  else
    $a = "Can't create report file !";
  return $a;

}

function wpcheck_cron() {
  $a = "";
  $mev = array();
  $mcrons  = _get_cron_array();

  if(empty($mcrons)) 
    return wpcheck_write("Cron jobs","Nothing found",0);

  foreach($mcrons as $time=>$mcron) {
    foreach($mcron as $mhook=>$md1) {
      foreach($md1 as $msig=>$data) {
        $mev["$mhook"]=(object) array(
          'hook'     =>$mhook,
          'time'     =>$time,
          'sig'      =>$msig,
          'args'     =>$data['args'],
          'schedule' =>$data['schedule'],
          'interval' =>isset($data['interval'])?$data['interval']:null,
        );
      }
    }
  }
  
  $a .= "<table>";
  $a .= "<tr><td><strong>Hook name</strong></td><td><strong>Recurence</strong></td><td><strong>Next execution</strong></td></tr>\n"; 
  foreach($mev as $mcl) {
    $a .= "<tr>";
    $a .= "<td>".$mcl->hook."</td>\n";
    $a .= "<td>".$mcl->schedule."</td>\n";
    $a .= "<td>".strftime("%a, %d %h %G %H:%M:%S",$mcl->time)."</td>\n";
    $a .= "</tr>";
  }
  $a .= "</table>";
  return $a;
}

function wpcheck_wordpress() {
  global $wp_version;
  $www = 'https://wordpress.org';
  $a = "";
  $a .= "<table>";
  $a .= wpcheck_write("Release",$wp_version,0);
  $a .= wpcheck_write("Site URL",site_url(),0);
  $a .= wpcheck_write("Site name",get_bloginfo('blogname'),0);
  $a .= wpcheck_write("Site description",get_bloginfo('description'),0);
  $a .= wpcheck_write("Admin email",get_bloginfo('admin_email'),0);
  $a .= wpcheck_write("Charset",get_bloginfo('charset'),0);
  $a .= wpcheck_write("Content-type",get_bloginfo('html_type'),0);
  $a .= wpcheck_write("Language",get_bloginfo('language'),0);
  $a .= wpcheck_write("Theme URL",get_template_directory(),0);
  $a .= wpcheck_write("Stylesheet",get_bloginfo('stylesheet_url'),0);
  $a .= wpcheck_write("Pingback XML-RPC file URL",get_bloginfo('pingback_url'),0);
  $a .= wpcheck_write("Atom feed URL",get_bloginfo('atom_url'),0);
  $a .= wpcheck_write("RDF/RSS 1.0 feed URL",get_bloginfo('rdf_url'),0);
  $a .= wpcheck_write("RSS 0.92 feed URL",get_bloginfo('rss_url'),0);
  $a .= wpcheck_write("RSS 2.0 feed URL",get_bloginfo('rss2_url'),0);
  $a .= wpcheck_write("Comments Atom feed URL",get_bloginfo('comments_atom_url'),0);
  $a .= wpcheck_write("Comments RSS 2.0 feed URL",get_bloginfo('comments_rss2_url'),0);
  $a .= wpcheck_write("Home path",get_home_path(),0);
  $a .= wpcheck_write("Admin URL",admin_url(),0);
  $a .= wpcheck_write("Includes URL",includes_url(),0);
  $a .= wpcheck_write("Content URL",content_url(),0);
  $a .= wpcheck_write("Plugins URL",plugins_url(),0);
  $t = wp_upload_dir();
  $a .= wpcheck_write("Upload base URL",$t['baseurl'],0);
  $a .= wpcheck_write("Upload current URL",$t['path'],0);

  $j = "Disabled";
  if (is_multisite())
    $j = "Enabled";
  $a .= wpcheck_write("Multisite",$j,0);


  $n = get_option("blacklist_keys");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Comment blacklist words",$n,0);
  $n = get_option("comment_max_links");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Hold a comment in the queue if it contains this value or more links",$n,0);
  $n = get_option("comment_moderation");
  if(!$n)
    $n = "False";
  else
    $n = "True";
  $a .= wpcheck_write("Before a comment appears, an administrator must always approve the comment",$n,0);
  $n = get_option("comments_notify");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("E-mail me when anyone posts a comment",$n,0);
  $n = get_option("default_comment_status");
  if($n == 'open')
    $n = "Allow comments";
  else
    $n = "Disallow comments";
  $a .= wpcheck_write("Allow comments (can be overridden with individual posts)",$n,0);
  $n = get_option("default_ping_status");
  if($n == 'open')
    $n = "Allow pingbacks and trackbacks from other blogs";
  else
    $n = "Disallow pingbacks and trackbacks from other blogs";
  $a .= wpcheck_write("Allow link notifications from other blogs (pingbacks and trackbacks)",$n,0);
  $n = get_option("default_pingback_flag");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Attempt to notify any blogs linked to from the article (slows down posting)",$n,0);
  $n = get_option("moderation_keys");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Hold comment if it contains this value",$n,0);
  $n = get_option("moderation_notify");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("E-mail me when a comment is held for moderation",$n,0);
  $n = get_option("require_name_email");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Before a comment appears, the comment author must fill out his/her name and email",$n,0);
  $n = get_option("thread_comments");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Enable WP-native threaded (nested) comments",$n,0);
  $n = get_option("thread_comments_depth");
  $a .= wpcheck_write("Set the number of threading levels for comments",$n,0);
  $n = get_option("show_avatars");
  if($n)
    $n = "Show avatars";
  else
    $n = "Do not show avatars";
  $a .= wpcheck_write("Avatar Display",$n,0);
  $n = get_option("avatar_rating");
  switch($n) {
    case "PG":
      $n = "Possibly offensive, usually for audiences 13 and above";
      break;
    case "R":
      $n = "Intended for adult audiences above 17";
      break;
    case "X":
      $n = "Even more mature than above";
      break;
    default:
      $n = "Suitable for all audiences";
      break;
  }
  $a .= wpcheck_write("Maximum Rating",$n,0);
  $n = get_option("avatar_default");
  switch($n) {
    case "blank":
      $n = "Blank";
      break;
    case "identicon":
      $n = "Identicon";
      break;
    case "wavatar":
      $n = "Wavatar";
      break;
    case "monsterid":
      $n = "MonsterID";
      break;
    case "retro":
      $n = "Retro";
      break;
    case "gravatar_default":
      $n = "Gravatar Logo";
      break;
    default:
      $n = "Mystery Man";
      break;
  }
  $a .= wpcheck_write("Default Avatar",$n,0);
  $n = get_option("close_comments_for_old_posts");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Automatically close comments on old articles",$n,0);
  $n = get_option("close_comments_days_old");
  $a .= wpcheck_write("Automatically close comments on articles older than x days",$n,0);
  $n = get_option("show_comments_cookies_opt_in");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Show the cookies opt-in checkbox on the comment form and enable comment cookies",$n,0);
  $n = get_option("page_comments");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Break comments into pages",$n,0);
  $n = get_option("comments_per_page");
  $a .= wpcheck_write("Comments per page",$n,0);
  $n = get_option("default_comments_page");
  $a .= wpcheck_write("Default comments page",$n,0);
  $n = get_option("comment_order");
  if($n == 'asc')
    $n = "Ascending";
  else
    $n = "Descending";
  $a .= wpcheck_write("Comment order",$n,0);
  $n = get_option("comment_whitelist");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Comment author must have a previously approved comment",$n,0);
  $n = get_option("comment_registration");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Users must be registered and logged in to comment",$n,0);
  $n = get_option("date_format");
  $a .= wpcheck_write("Default date format",$n,0);
  $n = get_option("default_role");
  $a .= wpcheck_write("The default role of users who register at the blog",$n,0);
  $n = get_option("gmt_offset");
  switch($n) {
    case "-6":
      $n = "GMT -6 (aka Central Time, USA)";
      break;
    case "0":
      $n = "GMT (aka Greenwich Mean Time)";
      break;
    default:
      $n = "date('Z') / 3600";
      break;
  }
  $a .= wpcheck_write("Times in the blog should differ by this value",$n,0);
  $n = get_option("start_of_week");
  switch($n) {
    default:
      $n = "Sunday";
      break;
    case 1:
      $n = "Monday";
      break;
    case 2:
      $n = "Tuesday";
      break;
    case 3:
      $n = "Wednesday";
      break;
    case 4:
      $n = "Thursday";
      break;
    case 5:
      $n = "Friday";
      break;
    case 6:
      $n = "Saturday";
      break;
  }
  $a .= wpcheck_write("The starting day of the week",$n,0);
  $n = get_option("time_format");
  $a .= wpcheck_write("Default time format",$n,0);
  $n = get_option("timezone_string");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Timezone",$n,0);
  $n = get_option("users_can_register");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Anyone can register",$n,0);
  $n = get_option("links_updated_date_format");
  $a .= wpcheck_write("Links updated date format",$n,0);
  $n = get_option("links_recently_updated_prepend");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Links recently updated prepend",$n,0);
  $n = get_option("links_recently_updated_append");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Links recently updated append",$n,0);
  $n = get_option("links_recently_updated_time");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Links recently updated time",$n,0);
  $n = get_option("thumbnail_size_w");
  $a .= wpcheck_write("Thumbnail size width",$n,0);
  $n = get_option("thumbnail_size_h");
  $a .= wpcheck_write("Thumbnail size height",$n,0);
  $n = get_option("thumbnail_crop");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Crop thumbnail to exact dimensions (normally thumbnails are proportional)",$n,0);
  $n = get_option("medium_size_w");
  $a .= wpcheck_write("Medium media size width",$n,0);
  $n = get_option("medium_size_h");
  $a .= wpcheck_write("Medium media size height",$n,0);
  $n = get_option("large_size_w");
  $a .= wpcheck_write("Large media size width",$n,0);
  $n = get_option("large_size_h");
  $a .= wpcheck_write("Large media size height",$n,0);
  $n = get_option("embed_autourls");
  $a .= wpcheck_write("Attempt to automatically embed all plain text URLs",$n,0);
  $n = get_option("embed_size_w");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Embeded media size width",$n,0);
  $n = get_option("embed_size_h");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Embeded media size height",$n,0);
  $n = get_option("hack_file");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Use legacy my-hacks.php file support",$n,0);
  $n = get_option("html_type");
  $a .= wpcheck_write("Default MIME type for blog pages (text/html, text/xml+html, etc.)",$n,0);
  $n = get_option("secret");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Secret value created during installation used with salting, etc.",$n,0);
  $n = get_option("uploads_use_yearmonth_folders");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Organize my uploads into month- and year-based folders",$n,0);
  $n = get_option("use_linksupdate");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Track links' update times",$n,0);
  $n = get_option("permalink_structure");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("The desired structure of your blog's permalinks",$n,0);
  $n = get_option("category_base");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("The default category base of your blog categories permalink",$n,0);
  $n = get_option("tag_base");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("The default tag base for your blog tags permalink",$n,0);
  $n = get_option("blog_public");
  if($n == 1)
    $n = "I would like my blog to be visible to everyone, including search engines (like Google, Sphere, Technorati) and archivers";
  else
    $n = "I would like to block search engines, but allow normal visitors";
  $a .= wpcheck_write("Search Engine Visibility",$n,0);
  $n = get_option("gzipcompression");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("WordPress should compress articles (with gzip) if browsers ask for them",$n,0);
  $n = get_option("page_on_front");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("The ID of the page that should be displayed on the front page. Requires show_on_front's value to be page",$n,0);
  $n = get_option("page_for_posts");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("The ID of the page that displays posts. Useful when show_on_front's value is page",$n,0);
  $n = get_option("posts_per_page");
  $a .= wpcheck_write("Show at most x many posts on blog pages",$n,0);
  $n = get_option("posts_per_rss");
  $a .= wpcheck_write("Show at most x many posts in RSS feeds",$n,0);
  $n = get_option("rss_language");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Language for RSS feeds (metadata purposes only)",$n,0);
  $n = get_option("rss_use_excerpt");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Show an excerpt instead of the full text of a post in RSS feeds",$n,0);
  $n = get_option("show_on_front");
  if($n == 'posts')
    $n = "Your latest posts";
  else
    $n = "A static page (see page_on_front)";
  $a .= wpcheck_write("What to show on the front page",$n,0);
  $n = get_option("template");
  $a .= wpcheck_write("The slug of the currently activated theme",$n,0);
  $n = get_option("stylesheet");
  $a .= wpcheck_write("The slug of the currently activated stylesheet",$n,0);
  $n = get_option("default_category");
  $a .= wpcheck_write("ID of the category that posts will be put in by default",$n,0);
  $n = get_option("default_email_category");
  $a .= wpcheck_write("ID of the category that posts will be put in by default when written via e-mail",$n,0);
  $n = get_option("default_link_category");
  $a .= wpcheck_write("ID of the category that links will be put in by default",$n,0);
  $n = get_option("default_post_edit_rows");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Size of the post box (in lines)",$n,0);
  $n = get_option("mailserver_login");
  $a .= wpcheck_write("Mail server username for posting to WordPress by e-mail",$n,0);
  $n = get_option("mailserver_pass");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Mail server password for posting to WordPress by e-mail",$n,0);
  $n = get_option("mailserver_port");
  $a .= wpcheck_write("Mail server port for posting to WordPress by e-mail",$n,0);
  $n = get_option("mailserver_url");
  $a .= wpcheck_write("Mail server for posting to WordPress by e-mail",$n,0);
  $n = get_option("ping_sites");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("When you publish a new post, WordPress automatically notifies the following site update services",$n,0);
  $n = get_option("use_balanceTags");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Correct invalidly-nested XHTML automatically",$n,0);
  $n = get_option("use_smilies");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Convert emoticons like :-) and :P to graphics when displayed",$n,0);
  $n = get_option("use_trackback");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Enable sending and receiving of trackbacks",$n,0);
  $n = get_option("enable_app");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Enable the Atom Publishing Protocol",$n,0);
  $n = get_option("enable_xmlrpc");
  if($n)
    $n = "Yes";
  else
    $n = "No";
  $a .= wpcheck_write("Enable the WordPress, Movable Type, MetaWeblog and Blogger XML-RPC publishing protocols",$n,0);
  $n = get_option("active_plugins");
  foreach ($n as $key=>$val) {
    $a .= wpcheck_write("Active plugin '$key'",$val,0);
  }
  $n = get_option("advanced_edit");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Advanced edit",$n,0);
  $n = get_option("recently_edited");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Recently edited",$n,0);
  $n = get_option("image_default_link_type");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Image default link type",$n,0);
  $n = get_option("image_default_size");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Image default size",$n,0);
  $n = get_option("image_default_align");
  if(!$n)
    $n = "Empty";
  $a .= wpcheck_write("Image default align",$n,0);

  foreach ($_COOKIE as $key=>$val) {
    $a .= wpcheck_write("Cookie '$key'",$val,0);
  }

  $a .= "</table>";
  return $a;
}

function wpcheck_httpd() {
  $a = "";
  $sof = $_SERVER['SERVER_SOFTWARE'];
  $j = "???";
  if(strlen($sof))
    $j = $sof;
  $a .= wpcheck_write("Server software",$j,0);
  return $a;
}

function wpcheck_performances() {
  $a = "";
  $a .= "<table>";
  $www = 'https://wordpress.org';
  $j = "KO !";
  $v = 0;
  $ts = 0;
  $ts1 = microtime(true);
  $fd = fopen($www, "r");
  if ($fd) {
    while (!feof ($fd)) {
      $li = fgets ($fd, 1024);
      $v += strlen($li);
      if(stristr($li,"wordpress.org"))
        $j = "OK";
    }
    $ts2 = microtime(true);
    $ts = $ts2 - $ts1;
    fclose($fd);
  }
  $a .= wpcheck_write("Fopen() to wordpress.org",$j,0);
  if($ts) {
    $j = sprintf("%d bytes in %0.04f μs",$v,$ts);
    $a .= wpcheck_write("Download time",$j,0);
  }
  $cok = 0;
  if (wpcheck_function_enabled("curl_version")) {
    $cl = curl_init();
    curl_setopt($cl, CURLOPT_URL, $www);
    curl_setopt($cl, CURLOPT_RETURNTRANSFER, true);
    $ts1 = microtime(true);
    $rt = curl_exec($cl);
    $ts2 = microtime(true);
    $ts = $ts2 - $ts1;
    $rc = curl_getinfo($cl, CURLINFO_HTTP_CODE);
    curl_close($cl);
    $j = "KO ! (".$rc.")";
    if(stristr($rt,"wordpress.org"))
      $j = "OK (".$rc.")";
    $a .= wpcheck_write("Curl() to wordpress.org",$j,0);
    if($ts) {
      $v = strlen($rt);
      $j = sprintf("%d bytes in %0.04f μs",$v,$ts);
      $a .= wpcheck_write("Download time",$j,0);
    }
  }
  else
    $a .= wpcheck_write("Curl tests","Cannot run tests as curl is disabled",0);
  $j = "KO";
  $ts = 0;
  $v = 0;
  $ts1 = microtime(true);
  $r = wp_remote_get($www, array( 'timeout' => 3, 'httpversion' => '1.1' ) );
  if ( is_array( $r ) ) {
    $ts2 = microtime(true);
    $ts = $ts2 - $ts1;
    $b = $r['body'];
    $v = strlen($b);
    $cc = $r['response']['code'];
    if($cc < 400)
      $j = "OK ";
    else
      $j = "KO ";
    $j .= "(". $cc.")";
  }
  $a .= wpcheck_write("wp_remote_get() to wordpress.org",$j,0);
  if($ts) {
    $j = sprintf("%d bytes in %0.04f μs",$v,$ts);
    $a .= wpcheck_write("Download time",$j,0);
  }
  $www = 'https://www.facebook.com';
  $j = "KO";
  $ts = 0;
  $v = 0;
  $ts1 = microtime(true);
  $r = wp_remote_get($www, array( 'timeout' => 3, 'httpversion' => '1.1' ) );
  if ( is_array( $r ) ) {
    $ts2 = microtime(true);
    $ts = $ts2 - $ts1;
    $b = $r['body'];
    $v = strlen($b);
    $cc = $r['response']['code'];
    if($cc < 400)
      $j = "OK ";
    else
      $j = "KO ";
    $j .= "(". $cc.")";
  }
  $a .= wpcheck_write("wp_remote_get() to facebook.com",$j,0);
  if($ts) {
    $j = sprintf("%d bytes in %0.04f μs",$v,$ts);
    $a .= wpcheck_write("Download time",$j,0);
  }
  $a .= "</table>";
  return $a;
}

function wpcheck_php_sw($u,$i) {
  $j = ini_get($u);
  if($i) {
    if(!strlen($j))
      $j = "Disabled";
    else
      $j = "Enabled";
  }
  else {
    if(!strlen($j))
      $j = "Empty";
    else
      $j = htmlentities($j);
  }
  return wpcheck_write($u,$j,0);
}

function wpcheck_php() {
  $a = "";
  $a .= "<table>";
  $www = 'https://wordpress.org';
  
  $a .= wpcheck_php_sw('allow_url_fopen',1);
  $a .= wpcheck_php_sw('allow_url_include',1);
  $a .= wpcheck_php_sw('always_populate_raw_post_data',0);
  $a .= wpcheck_php_sw('arg_separator.input',0);
  $a .= wpcheck_php_sw('arg_separator.output',0);
  $a .= wpcheck_php_sw('asp_tags',1);
  $a .= wpcheck_php_sw('auto_append_file',1);
  $a .= wpcheck_php_sw('auto_detect_line_endings',1);
  $a .= wpcheck_php_sw('auto_globals_jit',1);
  $a .= wpcheck_php_sw('auto_prepend_file',1);
  if(extension_loaded('bcmath'))
    $a .= wpcheck_write("BCMath support","Enabled",0);
  else
    $a .= wpcheck_write("BCMath support","Disabled",0);
  $a .= wpcheck_php_sw('bcmath.scale',0);
  $a .= wpcheck_php_sw('birdstep.max_links',0);
  if(extension_loaded('bz2'))
    $a .= wpcheck_write("Bzip2 support","Enabled",0);
  else
    $a .= wpcheck_write("Bzip2 support","Disabled",0);
  $a .= wpcheck_php_sw('browscap',0);
  if(extension_loaded('calendar'))
    $a .= wpcheck_write("Calendar support","Enabled",0);
  else
    $a .= wpcheck_write("Calendar support","Disabled",0);
  $a .= wpcheck_php_sw('cgi.fix_pathinfo',1);
  $a .= wpcheck_php_sw('cgi.force_redirect',1);
  $a .= wpcheck_php_sw('cgi.nph',1);
  $a .= wpcheck_php_sw('cgi.redirect_status_env',1);
  $a .= wpcheck_php_sw('cgi.rfc2616_headers',1);
  $a .= wpcheck_php_sw('cli_server.color',1);
  if(extension_loaded('ctype'))
    $a .= wpcheck_write("Ctype functions","Enabled",0);
  else
    $a .= wpcheck_write("Ctype functions","Disabled",0);
  $cok = 0;
  if (wpcheck_function_enabled("curl_version")) {
    $j = "Enabled";
    $cok = 1;
  }
  $a .= wpcheck_write("Curl",$j,0);
  if($cok) {
    $c = curl_version();
    $j = "???";
    $cv = $c["version"];
    if(strlen($cv))
      $j = $cv;
    $a .= wpcheck_write("Curl host",$c['host'],0);
    $a .= wpcheck_write("Curl SSL version",$c['ssl_version'],0);
    $a .= wpcheck_write("Curl version",$j,0);
  }
  if(extension_loaded('Date'))
    $a .= wpcheck_write("Date/time support","Enabled",0);
  else
    $a .= wpcheck_write("Date/time support","Disabled",0);
  $a .= wpcheck_php_sw('date.default_latitude',0);
  $a .= wpcheck_php_sw('date.default_longitude',0);
  $a .= wpcheck_php_sw('date.sunrise_zenith',0);
  $a .= wpcheck_php_sw('date.sunset_zenith',0);
  $a .= wpcheck_php_sw('date.timezone',0);
  $a .= wpcheck_php_sw('default_charset',0);
  $a .= wpcheck_php_sw('default_mimetype',0);
  $a .= wpcheck_php_sw('default_socket_timeout',0);
  $a .= wpcheck_write("Default timezone",date_default_timezone_get(),0);
  $a .= wpcheck_php_sw('disable_classes',0);
  $a .= wpcheck_php_sw('disable_functions',0);
  $a .= wpcheck_php_sw('display_errors',1);
  $a .= wpcheck_php_sw('display_startup_errors',1);
  $a .= wpcheck_php_sw('doc_root',0);
  $a .= wpcheck_php_sw('docref_ext',0);
  $a .= wpcheck_php_sw('docref_root',0);
  if(extension_loaded('dom'))
    $a .= wpcheck_write("DOM/XML","Enabled",0);
  else
    $a .= wpcheck_write("DOM/XML","Disabled",0);
  if(extension_loaded('standard'))
    $a .= wpcheck_write("Dynamic Library Support","Enabled",0);
  else
    $a .= wpcheck_write("Dynamic Library Support","Disabled",0);
  $a .= wpcheck_php_sw('enable_dl',1);
  $a .= wpcheck_php_sw('enable_post_data_reading',1);
  $a .= wpcheck_php_sw('engine',1);
  if(extension_loaded('ereg'))
    $a .= wpcheck_write("Regex Library","Enabled",0);
  else
    $a .= wpcheck_write("Regex Library","Disabled",0);
  $a .= wpcheck_php_sw('error_append_string',0);
  $a .= wpcheck_php_sw('error_log',0);
  $a .= wpcheck_php_sw('error_prepend_string',0);
  $j = ini_get('error_reporting');
  if($j&E_ALL)
    $m .= "E_ALL<br />";
  if($j&E_ERROR)
    $m .= "E_ERROR<br />";
  if($j&E_RECOVERABLE_ERROR)
    $m .= "E_RECOVERABLE_ERROR<br />";
  if($j&E_WARNING)
    $m .= "E_WARNING<br />";
  if($j&E_PARSE)
    $m .= "E_PARSE<br />";
  if($j&E_NOTICE)
    $m .= "E_NOTICE<br />";
  if($j&E_STRICT)
    $m .= "E_STRICT<br />";
  if($j&E_CORE_ERROR)
    $m .= "E_CORE_ERROR<br />";
  if($j&E_CORE_WARNING)
    $m .= "E_CORE_WARNING<br />";
  if($j&E_COMPILE_ERROR)
    $m .= "E_COMPILE_ERROR<br />";
  if($j&E_COMPILE_WARNING)
    $m .= "E_COMPILE_WARNING<br />";
  if($j&E_USER_ERROR)
    $m .= "E_USER_ERROR<br />";
  if($j&E_USER_WARNING)
    $m .= "E_USER_WARNING<br />";
  if($j&E_USER_NOTICE)
    $m .= "E_USER_NOTICE<br />";
  if($j&E_DEPRECATED)
    $m .= "E_DEPRECATED<br />";
  if($j&E_USER_DEPRECATED)
    $m .= "E_USER_DEPRECATED<br />";
  $a .= wpcheck_write("error_reporting",$m,0);
  if(extension_loaded('exif'))
    $a .= wpcheck_write("EXIF support","Enabled",0);
  else
    $a .= wpcheck_write("EXIF support","Disabled",0);
  $a .= wpcheck_php_sw('expose_php',1);
  $a .= wpcheck_php_sw('extension_dir',0);
  $a .= wpcheck_php_sw('fastcgi.impersonate',1);
  $a .= wpcheck_php_sw('fastcgi.logging',1);
  $a .= wpcheck_php_sw('file_uploads',1);
  if(extension_loaded('fileinfo'))
    $a .= wpcheck_write("Fileinfo support","Enabled",0);
  else
    $a .= wpcheck_write("Fileinfo support","Disabled",0);
  $a .= wpcheck_php_sw('filter.default',0);
  $a .= wpcheck_php_sw('filter.default_flags',0);
  $a .= wpcheck_php_sw('from',0);
  if(extension_loaded('ftp'))
    $a .= wpcheck_write("Ftp support","Enabled",0);
  else
    $a .= wpcheck_write("Ftp support","Disabled",0);
  if(extension_loaded('gd')) {
    $g = gd_info();
    if($g['FreeType Linkage'])
      $a .= wpcheck_write("Gd FreeType Linkage","Enabled",0);
    else
      $a .= wpcheck_write("Gd FreeType Linkage","Disabled",0);
    if($g['FreeType Support'])
      $a .= wpcheck_write("Gd FreeType Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd FreeType Support","Disabled",0);
    if($g['GIF Create Support'])
      $a .= wpcheck_write("Gd GIF Create Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd GIF Create Support","Disabled",0);
    if($g['GIF Read Support'])
      $a .= wpcheck_write("Gd GIF Read Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd GIF Read Support","Disabled",0);
    if($g['JPEG Support'])
      $a .= wpcheck_write("Gd JPEG Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd JPEG Support","Disabled",0);
    $a .= wpcheck_write("Gd library","Enabled",0);
    if($g['PNG Support'])
      $a .= wpcheck_write("Gd PNG Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd PNG Support","Disabled",0);
    if($g['T1Lib Support'])
      $a .= wpcheck_write("Gd T1Lib Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd T1Lib Support","Disabled",0);

    $a .= wpcheck_write("Gd version",$g['GD Version'],0);
    if($g['WBMP Support'])
      $a .= wpcheck_write("Gd WBMP Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd WBMP Support","Disabled",0);
    if($g['WebP Support'])
      $a .= wpcheck_write("Gd WebP Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd WebP Support","Disabled",0);
    if($g['XBM Support'])
      $a .= wpcheck_write("Gd XBM Support","Enabled",0);
    else
      $a .= wpcheck_write("Gd XBM Support","Disabled",0);
  }
  else
    $a .= wpcheck_write("Gd library","Disabled",0);
  if(extension_loaded('gettext'))
    $a .= wpcheck_write("GetText Support","Enabled",0);
  else
    $a .= wpcheck_write("GetText Support","Disabled",0);
  if(extension_loaded('gmp'))
    $a .= wpcheck_write("Gmp support","Enabled",0);
  else
    $a .= wpcheck_write("Gmp support","Disabled",0);
  if(extension_loaded('hash'))
    $a .= wpcheck_write("Hash support","Enabled",0);
  else
    $a .= wpcheck_write("Hash support","Disabled",0);
  $a .= wpcheck_php_sw('highlight.comment',0);
  $a .= wpcheck_php_sw('highlight.default',0);
  $a .= wpcheck_php_sw('highlight.html',0);
  $a .= wpcheck_php_sw('highlight.keyword',0);
  $a .= wpcheck_php_sw('highlight.string',0);
  $a .= wpcheck_php_sw('html_errors',1);

  $a .= wpcheck_php_sw('ibase.allow_persistent',0);
  $a .= wpcheck_php_sw('ibase.dateformat',0);
  $a .= wpcheck_php_sw('ibase.default_charset',0);
  $a .= wpcheck_php_sw('ibase.default_db',0);
  $a .= wpcheck_php_sw('ibase.default_password',0);
  $a .= wpcheck_php_sw('ibase.default_user',0);
  $a .= wpcheck_php_sw('ibase.max_links',0);
  $a .= wpcheck_php_sw('ibase.max_persistent',0);
  $a .= wpcheck_php_sw('ibase.timeformat',0);
  $a .= wpcheck_php_sw('ibase.timestampformat',0);

  if(extension_loaded('iconv'))
    $a .= wpcheck_write("Iconv support","Enabled",0);
  else
    $a .= wpcheck_write("Iconv support","Disabled",0);
  $a .= wpcheck_php_sw('iconv.input_encoding',0);
  $a .= wpcheck_php_sw('iconv.internal_encoding',0);
  $a .= wpcheck_php_sw('iconv.output_encoding',0);
  $a .= wpcheck_php_sw('ignore_repeated_errors',1);
  $a .= wpcheck_php_sw('ignore_repeated_source',1);
  $a .= wpcheck_php_sw('ignore_user_abort',1);
  $a .= wpcheck_php_sw('implicit_flush',1);
  $a .= wpcheck_php_sw('include_path',0);
  $a .= wpcheck_php_sw('input_encoding',0);
  if(extension_loaded('filter'))
    $a .= wpcheck_write("Input Validation and Filtering","Enabled",0);
  else
    $a .= wpcheck_write("Input Validation and Filtering","Disabled",0);
  $a .= wpcheck_php_sw('internal_encoding',0);
  $a .= wpcheck_php_sw('intl.error_level',0);
  if(extension_loaded('json'))
    $a .= wpcheck_write("Json support","Enabled",0);
  else
    $a .= wpcheck_write("Json support","Disabled",0);
  if(extension_loaded('libxml'))
    $a .= wpcheck_write("LibXML support","Enabled",0);
  else
    $a .= wpcheck_write("LibXML support","Disabled",0);
  if(extension_loaded('yaml'))
    $a .= wpcheck_write("LibYAML Support","Enabled",0);
  else 
    $a .= wpcheck_write("LibYAML Support","Disabled",0);
  $a .= wpcheck_php_sw('log_errors',1);
  $a .= wpcheck_php_sw('log_errors_max_len',0);
  $a .= wpcheck_php_sw('mail.add_x_header',1);
  $a .= wpcheck_php_sw('mail.force_extra_parameters',0);
  $a .= wpcheck_php_sw('mail.log',0);
  $a .= wpcheck_php_sw('max_execution_time',0);
  $a .= wpcheck_php_sw('max_file_uploads',0);
  $a .= wpcheck_php_sw('max_input_nesting_level',0);
  $a .= wpcheck_php_sw('max_input_time',0);
  $a .= wpcheck_php_sw('max_input_vars',0);
  $a .= wpcheck_php_sw('memory_limit',0);
  if(extension_loaded('mhash'))
    $a .= wpcheck_write("Mhash support","Enabled",0);
  else
    $a .= wpcheck_write("Mhash support","Disabled",0);
  if(extension_loaded('mbstring'))
    $a .= wpcheck_write("Multibyte Support","Enabled",0);
  else
    $a .= wpcheck_write("Multibyte Support","Disabled",0);

  $a .= wpcheck_php_sw('mysql.allow_local_infile',1);
  $a .= wpcheck_php_sw('mysql.allow_persistent',1);
  $a .= wpcheck_php_sw('mysql.cache_size',0);
  $a .= wpcheck_php_sw('mysql.connect_timeout',0);
  $a .= wpcheck_php_sw('mysql.default_host',0);
  $a .= wpcheck_php_sw('mysql.default_port',0);
  $a .= wpcheck_php_sw('mysql.default_socket',0);
  $a .= wpcheck_php_sw('mysql.default_password',0);
  $a .= wpcheck_php_sw('mysql.default_user',0);
  $a .= wpcheck_php_sw('mysql.max_links',0);
  $a .= wpcheck_php_sw('mysql.max_persistent',0);
  $a .= wpcheck_php_sw('mysql.trace_mode',1);

  $a .= wpcheck_php_sw('mysqli.allow_local_infile',1);
  $a .= wpcheck_php_sw('mysqli.allow_persistent',1);
  $a .= wpcheck_php_sw('mysqli.cache_size',0);
  $a .= wpcheck_php_sw('mysqli.default_host',0);
  $a .= wpcheck_php_sw('mysqli.default_port',0);
  $a .= wpcheck_php_sw('mysqli.default_pw',0);
  $a .= wpcheck_php_sw('mysqli.default_socket',0);
  $a .= wpcheck_php_sw('mysqli.default_user',0);
  $a .= wpcheck_php_sw('mysqli.max_links',0);
  $a .= wpcheck_php_sw('mysqli.max_persistent',0);
  $a .= wpcheck_php_sw('mysqli.reconnect',1);

  $a .= wpcheck_php_sw('mysqlnd.collect_statistics',1);
  $a .= wpcheck_php_sw('mysqlnd.collect_memory_statistics',1);
  $a .= wpcheck_php_sw('mysqlnd.net_cmd_buffer_size',0);
  $a .= wpcheck_php_sw('mysqlnd.net_read_buffer_size',0);

  $a .= wpcheck_php_sw('oci8.connection_class',0);
  $a .= wpcheck_php_sw('oci8.default_prefetch',0);
  $a .= wpcheck_php_sw('oci8.events',1);
  $a .= wpcheck_php_sw('oci8.max_persistent',0);
  $a .= wpcheck_php_sw('oci8.old_oci_close_semantics',1);
  $a .= wpcheck_php_sw('oci8.persistent_timeout',0);
  $a .= wpcheck_php_sw('oci8.ping_interval',0);
  $a .= wpcheck_php_sw('oci8.privileged_connect',1);
  $a .= wpcheck_php_sw('oci8.statement_cache_size',0);


  $a .= wpcheck_php_sw('odbc.allow_persistent',1);
  $a .= wpcheck_php_sw('odbc.check_persistent',1);
  $a .= wpcheck_php_sw('odbc.default_cursortype',0);
  $a .= wpcheck_php_sw('odbc.default_db',0);
  $a .= wpcheck_php_sw('odbc.default_pw',0);
  $a .= wpcheck_php_sw('odbc.default_user',0);
  $a .= wpcheck_php_sw('odbc.defaultbinmode',0);
  $a .= wpcheck_php_sw('odbc.defaultlrl',0);
  $a .= wpcheck_php_sw('odbc.max_links',0);
  $a .= wpcheck_php_sw('odbc.max_persistent',0);
  $a .= wpcheck_php_sw('open_basedir',0);
  if(extension_loaded('openssl'))
    $a .= wpcheck_write("OpenSSL support","Enabled",0);
  else
    $a .= wpcheck_write("OpenSSL support","Disabled",0);
  $a .= wpcheck_php_sw('output_buffering',0);
  $a .= wpcheck_php_sw('output_encoding',0);
  $a .= wpcheck_php_sw('output_handler',0);
  $a .= wpcheck_php_sw('pcre.backtrack_limit',0);
  $a .= wpcheck_php_sw('pcre.recursion_limit',0);
  if(extension_loaded('pdo_mysql'))
    $a .= wpcheck_write("PDO Driver for MySQL","Enabled",0);
  else
    $a .= wpcheck_write("PDO Driver for MySQL","Disabled",0);
  if(extension_loaded('pdo_sqlite'))
    $a .= wpcheck_write("PDO Driver for SQLite 3.x","Enabled",0);
  else
    $a .= wpcheck_write("PDO Driver for SQLite 3.x","Disabled",0);
  if(extension_loaded('PDO'))
    $a .= wpcheck_write("PDO support","Enabled",0);
  else
    $a .= wpcheck_write("PDO support","Disabled",0);
  $a .= wpcheck_php_sw('pdo_odbc.connection_pooling',0);
  $a .= wpcheck_php_sw('pdo_odbc.db2_instance_name',0);
  $a .= wpcheck_php_sw('pdo_mysql.cache_size',0);
  $a .= wpcheck_php_sw('pdo_mysql.default_socket',0);
  if(extension_loaded('pcre'))
    $a .= wpcheck_write("Perl Compatible Regular Expressions Support","Enabled",0);
  else
    $a .= wpcheck_write("Perl Compatible Regular Expressions Support","Disabled",0);

  $a .= wpcheck_php_sw('pgsql.allow_persistent',1);
  $a .= wpcheck_php_sw('pgsql.auto_reset_persistent',1);
  $a .= wpcheck_php_sw('pgsql.ignore_notice',0);
  $a .= wpcheck_php_sw('pgsql.log_notice',0);
  $a .= wpcheck_php_sw('pgsql.max_links',0);
  $a .= wpcheck_php_sw('pgsql.max_persistent',0);

  $a .= wpcheck_php_sw('phar.cache_list',0);
  $a .= wpcheck_php_sw('phar.readonly',1);
  $a .= wpcheck_php_sw('phar.require_hash',1);
  if(extension_loaded('Phar'))
    $a .= wpcheck_write("PHP Archive support","Enabled",0);
  else
    $a .= wpcheck_write("PHP Archive support","Disabled",0);
  $a .= wpcheck_php_sw('precision',0);
  $a .= wpcheck_php_sw('post_max_size',0);
  $a .= wpcheck_php_sw('register_argc_argv',1);
  $a .= wpcheck_php_sw('realpath_cache_size',0);
  $a .= wpcheck_php_sw('realpath_cache_ttl',0);
  if(extension_loaded('Reflection'))
    $a .= wpcheck_write("Reflection support","Enabled",0);
  else
    $a .= wpcheck_write("Reflection support","Disabled",0);
  $a .= wpcheck_write("Release",phpversion(),0);
  $a .= wpcheck_php_sw('report_memleaks',1);
  $a .= wpcheck_php_sw('report_zend_debug',1);
  $a .= wpcheck_php_sw('request_order',0);
  $a .= wpcheck_php_sw('sendmail_path',0);
  $a .= wpcheck_php_sw('serialize_precision',0);
  if(extension_loaded('session'))
    $a .= wpcheck_write("Session support","Enabled",0);
  else
    $a .= wpcheck_write("Session support","Disabled",0);
 
  $a .= wpcheck_php_sw('session.auto_start',0);
  $a .= wpcheck_php_sw('session.cache_expire',0);
  $a .= wpcheck_php_sw('session.cache_limiter',0);
  $a .= wpcheck_php_sw('session.cookie_domain',0);
  $a .= wpcheck_php_sw('session.cookie_httponly',0);
  $a .= wpcheck_php_sw('session.cookie_lifetime',0);
  $a .= wpcheck_php_sw('session.cookie_path',0);
  $a .= wpcheck_php_sw('session.cookie_secure',0);
  $a .= wpcheck_php_sw('session.entropy_file',0);
  $a .= wpcheck_php_sw('session.entropy_length',0);
  $a .= wpcheck_php_sw('session.gc_divisor',0);
  $a .= wpcheck_php_sw('session.gc_probability',0);
  $a .= wpcheck_php_sw('session.gc_maxlifetime',0);
  $a .= wpcheck_php_sw('session.hash_bits_per_character',0);
  $a .= wpcheck_php_sw('session.hash_function',0);
  $a .= wpcheck_php_sw('session.name',0);
  $a .= wpcheck_php_sw('session.referer_check',0);
  $a .= wpcheck_php_sw('session.save_handler',0);
  $a .= wpcheck_php_sw('session.save_path',0);
  $a .= wpcheck_php_sw('session.serialize_handler',0);
  $a .= wpcheck_php_sw('session.upload_progress.cleanup',1);
  $a .= wpcheck_php_sw('session.upload_progress.enabled',0);
  $a .= wpcheck_php_sw('session.upload_progress.freq',0);
  $a .= wpcheck_php_sw('session.upload_progress.min_freq',0);
  $a .= wpcheck_php_sw('session.upload_progress.name',0);
  $a .= wpcheck_php_sw('session.upload_progress.prefix',0);
  $a .= wpcheck_php_sw('session.use_cookies',0);
  $a .= wpcheck_php_sw('session.use_only_cookies',0);
  $a .= wpcheck_php_sw('session.use_strict_mode',0);
  $a .= wpcheck_php_sw('session.use_trans_sid',0);

  $j = "Disabled";
  if(wpcheck_function_enabled("shell_exec")) {
    $j = "Enabled";
  }
  $a .= wpcheck_write("shell_exec()",$j,0);
  if(extension_loaded('shmop'))
    $a .= wpcheck_write("Shmop support","Enabled",0);
  else
    $a .= wpcheck_write("Shmop support","Disabled",0);
  $a .= wpcheck_php_sw('short_open_tag',0);
  if(extension_loaded('SimpleXML'))
    $a .= wpcheck_write("SimpleXML support","Enabled",0);
  else
    $a .= wpcheck_write("SimpleXML support","Disabled",0);
  $j = "???";
  $i = ini_get("SMTP");
  if(strlen($i))
    $j = $i;
  $a .= wpcheck_write("SMTP",$j,0);
  $j = "???";
  $i = ini_get("smtp_port");
  if(strlen($i))
    $j = $i;
  $a .= wpcheck_write("SMTP Port",$j,0);
  if(extension_loaded('sockets'))
    $a .= wpcheck_write("Sockets support","Enabled",0);
  else
    $a .= wpcheck_write("Socket support","Disabled",0);
  if(extension_loaded('SPL'))
    $a .= wpcheck_write("SPL support","Enabled",0);
  else
    $a .= wpcheck_write("SPL support","Disabled",0);
  $a .= wpcheck_php_sw('sql.safe_mode',1);
  $a .= wpcheck_php_sw('sqlite.assoc_case',0);
  if(extension_loaded('sqlite3'))
    $a .= wpcheck_write("SQLite3 support","Enabled",0);
  else
    $a .= wpcheck_write("SQLite3 support","Disabled",0);
  $a .= wpcheck_php_sw('sqlite3.extension_dir',0);

  $a .= wpcheck_php_sw('sybct.allow_persistent',1);
  $a .= wpcheck_php_sw('sybct.deadlock_retry_count',0);
  $a .= wpcheck_php_sw('sybct.hostname',0);
  $a .= wpcheck_php_sw('sybct.login_timeout',0);
  $a .= wpcheck_php_sw('sybct.max_links',0);
  $a .= wpcheck_php_sw('sybct.max_persistent',0);
  $a .= wpcheck_php_sw('sybct.min_client_severity',0);
  $a .= wpcheck_php_sw('sybct.min_server_severity',0);
  $a .= wpcheck_php_sw('sybct.packet_size',0);
  $a .= wpcheck_php_sw('sybct.timeout',0);

  $a .= wpcheck_php_sw('sys_temp_dir',0);
  $j = "Disabled";
  if(wpcheck_function_enabled("system")) {
    $j = "Enabled";
  }
  $a .= wpcheck_write("system()",$j,0);
  if(extension_loaded('sysvmsg'))
    $a .= wpcheck_write("Sysvmsg support","Enabled",0);
  else
    $a .= wpcheck_write("Sysvmsg support","Disabled",0);
  if(extension_loaded('tidy'))
    $a .= wpcheck_write("Tidy support","Enabled",0);
  else
    $a .= wpcheck_write("Tidy support","Disabled",0);
  if(extension_loaded('tokenizer'))
    $a .= wpcheck_write("Tokenizer Support","Enabled",0);
  else 
    $a .= wpcheck_write("Tokenizer Support","Disabled",0);
  $a .= wpcheck_php_sw('track_errors',1);
  $a .= wpcheck_php_sw('unserialize_callback_func',0);
  $a .= wpcheck_php_sw('upload_tmp_dir',0);
  $a .= wpcheck_php_sw('url_rewriter.tags',0);
  $a .= wpcheck_php_sw('user_agent',0);
  $a .= wpcheck_php_sw('user_dir',0);
  $a .= wpcheck_php_sw('user_ini.cache_ttl',0);
  $a .= wpcheck_php_sw('user_ini.filename',0);
  $a .= wpcheck_php_sw('variables_order',0);
  if(extension_loaded('wddx'))
    $a .= wpcheck_write("WDDX Support","Enabled",0);
  else
    $a .= wpcheck_write("WDDX Support","Disabled",0);
  $a .= wpcheck_php_sw('windows.show_crt_warning',0);
  if(extension_loaded('xmlreader'))
    $a .= wpcheck_write("XML reader support","Enabled",0);
  else
    $a .= wpcheck_write("XML reader support","Disabled",0);
  if(extension_loaded('xml')) 
    $a .= wpcheck_write("XML support","Enabled",0);
  else
    $a .= wpcheck_write("XML support","Disabled",0);
  if(extension_loaded('xmlwriter'))
    $a .= wpcheck_write("XML writer support","Enabled",0);
  else
    $a .= wpcheck_write("XML writer support","Disabled",0);

  $a .= wpcheck_php_sw('xmlrpc_errors',1);
  $a .= wpcheck_php_sw('xmlrpc_errors_number',1);
  if(extension_loaded('xsl'))
    $a .= wpcheck_write("XSL support","Enabled",0);
  else
    $a .= wpcheck_write("XSL support","Disabled",0);
  $a .= wpcheck_php_sw('zend.enable_gc',1);
  $a .= wpcheck_php_sw('zend.multibyte',1);
  $a .= wpcheck_php_sw('zend.script_encoding',0);
  if(extension_loaded('zip'))
    $a .= wpcheck_write("Zip support","Enabled",0);
  else
    $a .= wpcheck_write("Zip support","Disabled",0);
  if(extension_loaded('zlib'))
    $a .= wpcheck_write("Zlib support","Enabled",0);
  else
    $a .= wpcheck_write("Zlib support","Disabled",0);
  $a .= wpcheck_php_sw('zlib.output_compression',1);
  $a .= wpcheck_php_sw('zlib.output_compression_level',0);
  $a .= wpcheck_php_sw('zlib.output_handler',0);

  $a .= "</table>";
  return $a;
}

function wpcheck_sys() {
  $a = "";
  error_reporting(E_ERROR | E_PARSE);
  $jshl = "Disabled";
  if(wpcheck_function_enabled("shell_exec")) {
    $msysok = 1;
    $jshl = "Enabled";
  }
 
  $a .= "<table>";

  if($msysok) {
    $mexq = "uname";
    $j = "???";
    $mos = strtolower(trim(shell_exec($mexq)));
    if(strlen($mos))
      $j = $mos;
    $a .= wpcheck_write("Operating system",$j,0);
 
  }
  $a .= wpcheck_write("OS Kernel",php_uname(),0);
  $j = "???";
  $n = $_SERVER['SERVER_NAME'];
  if(strlen($n))
    $j = $n;
  $a .= wpcheck_write("Server name",$n,0);
  $dt = sprintf("%4d-%02d-%02d %02d:%02d:%02d",date('Y'),date('n'), date('d') , date('H'),date('i'),date('s'));
  $a .= wpcheck_write("Local time",$dt,0);
  $j = "???";
  $mh = gethostname();
  if(strlen($mh))
    $j = $mh;
  $a .= wpcheck_write("Hostname",$j,0);
  $j = "???";
  $n = $_SERVER['SERVER_ADDR'];
  if(strlen($n))
    $j = $n;
  $a .= wpcheck_write("Server address",$j,0);
  $j = "Disabled";
  if ((!empty($_SERVER['HTTPS']) && $_SERVER['HTTPS'] !== 'off') || $_SERVER['SERVER_PORT'] == 443)
    $j = "Enabled";
  $a .= wpcheck_write("SSL",$j,0);
  $mip = "???";
  if($_SERVER['HTTP_CLIENT_IP'])
    $mip = $_SERVER['HTTP_CLIENT_IP'];
  else if($_SERVER['HTTP_X_FORWARDED_FOR'])
    $mip = $_SERVER['HTTP_X_FORWARDED_FOR'];
  else if($_SERVER['HTTP_X_FORWARDED'])
    $mip = $_SERVER['HTTP_X_FORWARDED'];
  else if($_SERVER['HTTP_FORWARDED_FOR'])
    $mip = $_SERVER['HTTP_FORWARDED_FOR'];
  else if($_SERVER['HTTP_FORWARDED'])
     $mip = $_SERVER['HTTP_FORWARDED'];
  else if($_SERVER['REMOTE_ADDR'])
    $mip = $_SERVER['REMOTE_ADDR'];
  $a .= wpcheck_write("Your IP address",$mip,0);
  $j = "???";
  $n = $_SERVER['REMOTE_PORT'];
  if(strlen($n))
    $j = $n;
  $a .= wpcheck_write("Your port","TCP/".$j,0);
  $j = "???";
  $ua = $_SERVER['HTTP_USER_AGENT'];
  if(strlen($j))
    $j = $ua;
  $a .= wpcheck_write("User agent",$ua,0);
  $a .= "</table>";
  return $a;
}

function wpcheck_net() {
  $a = "";
  $a .= "<table>";

  $a .= "<table>";
  return $a;
}

function wpcheck_page_tabs($current='f1') {
  $tabs = array(
    'f1'   => __('System', 'plugin-textdomain'),
    'f2'  => __('Php', 'plugin-textdomain'),
    'f3'  => __('Wordpress', 'plugin-textdomain'),
    'f4'  => __('Cron', 'plugin-textdomain'),
    'f5'  => __('Performances', 'plugin-textdomain'),
    'f6'  => __('Report', 'plugin-textdomain')
  );
  $html = '<h2 class="nav-tab-wrapper">';
  foreach( $tabs as $tab => $name ){
    $class = ( $tab == $current ) ? 'nav-tab-active' : '';
    $html .= '<a class="nav-tab ' . $class . '" href="?page=wpcheck-admin-page&tab=' . $tab . '"><div class="wpcheck-menu-bk">' . $name . '</div></a>';
  }
  $html .= '</h2>';
  echo $html;
}

function wpcheck_display_settings() {
  error_reporting(E_ERROR | E_PARSE);
  $mtab = ( ! empty( $_GET['tab'] ) ) ? esc_attr( $_GET['tab'] ) : 'f1';
  wpcheck_page_tabs($mtab);
  switch($mtab) {
    default:
    case 'f1':
      $a = wpcheck_sys();
      break;
    case 'f2':
      $a = wpcheck_php();
      break;
    case 'f3':
      $a = wpcheck_wordpress();
      break;
    case 'f4':
      $a = wpcheck_cron();
      break;
    case 'f5':
      $a = wpcheck_performances();
      break;
    case 'f6':
      $a = wpcheck_report();
      break;
   } 
  echo $a;
}

require_once(ABSPATH . 'wp-includes/plugin.php');
register_activation_hook(__FILE__,'wpcheck_init');
register_deactivation_hook(__FILE__,'wpcheck_deinit');
add_action('admin_menu', 'wpcheck_admin_settings');
add_action('admin_enqueue_scripts', 'wpcheck_styles'); 
